[dpdk-dev] [RFC v2 03/26] bbdev: rename master to initial lcore

Stephen Hemminger stephen at networkplumber.org
Sat Jun 6 00:57:48 CEST 2020


Conform to new API.

Signed-off-by: Stephen Hemminger <stephen at networkplumber.org>
---
 examples/bbdev_app/main.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/examples/bbdev_app/main.c b/examples/bbdev_app/main.c
index fb38dc3a72cb..06288e7f8add 100644
--- a/examples/bbdev_app/main.c
+++ b/examples/bbdev_app/main.c
@@ -1040,7 +1040,7 @@ main(int argc, char **argv)
 	struct stats_lcore_params stats_lcore;
 	struct rte_ring *enc_to_dec_ring;
 	bool stats_thread_started = false;
-	unsigned int master_lcore_id = rte_get_master_lcore();
+	unsigned int initial_lcore_id = rte_get_initial_lcore();
 
 	rte_atomic16_init(&global_exit_flag);
 
@@ -1143,9 +1143,9 @@ main(int argc, char **argv)
 	stats_lcore.app_params = &app_params;
 	stats_lcore.lconf = lcore_conf;
 
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 		if (lcore_conf[lcore_id].core_type != 0)
 			/* launch per-lcore processing loop on slave lcores */
 			rte_eal_remote_launch(processing_loop,
 					&lcore_conf[lcore_id], lcore_id);
 		else if (!stats_thread_started) {
@@ -1157,15 +1157,15 @@ main(int argc, char **argv)
 	}
 
 	if (!stats_thread_started &&
-			lcore_conf[master_lcore_id].core_type != 0)
+			lcore_conf[initial_lcore_id].core_type != 0)
 		rte_exit(EXIT_FAILURE,
 				"Not enough lcores to run the statistics printing loop!");
-	else if (lcore_conf[master_lcore_id].core_type != 0)
-		processing_loop(&lcore_conf[master_lcore_id]);
+	else if (lcore_conf[initial_lcore_id].core_type != 0)
+		processing_loop(&lcore_conf[initial_lcore_id]);
 	else if (!stats_thread_started)
 		stats_loop(&stats_lcore);
 
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 		ret |= rte_eal_wait_lcore(lcore_id);
 	}
 
@@ -1143,9 +1143,9 @@ main(int argc, char **argv)
 		if (lcore_conf[lcore_id].core_type != 0)
-			/* launch per-lcore processing loop on slave lcores */
+			/* launch per-lcore processing loop on worker lcores */
 			rte_eal_remote_launch(processing_loop,
 					&lcore_conf[lcore_id], lcore_id);
-- 
2.26.2



More information about the dev mailing list